==> kadu_0.6.0.orig.tar.gz: kadu/modules/history/translations/history_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="53"/>
        <source>Chat</source>
        <translation>Okno rozmowy</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="6"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="9"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="12"/>
        <source>Save history</source>
        <translation>Zapisuj historię</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="14"/>
        <source>Save messages in history</source>
        <translation>Zapisuj wiadomości w historii</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="18"/>
        <source>Status changes</source>
        <translation>Zmiany statusów</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="21"/>
        <source>Don&apos;t show status changes</source>
        <translation>Nie pokazuj zmian statusów</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="23"/>
        <source>Don&apos;t show status changes in history</source>
        <translation>Nie pokazuje zmian statusów w historii</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="26"/>
        <source>Don&apos;t save status changes</source>
        <translation>Nie zapisuj zmian statusów</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="28"/>
        <source>Don&apos;t save status changes in history</source>
        <translation>Nie zapisuje zmian statusów w historii</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="32"/>
        <source>Citation</source>
        <translation>Cytowanie</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="35"/>
        <source>Message citation in chat window</source>
        <translation>Cytowanie historii w oknie rozmowy</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="38"/>
        <source>Don&apos;t cite messages older than</source>
        <translation>Nie cytuj historii starszej niż</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="41"/>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="47"/>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="56"/>
        <source>View history</source>
        <translation>Pokaż historię</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <location filename="../history_dialog.cpp" line="77"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="98"/>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="99"/>
        <source>Find &amp;next</source>
        <translation>Znajdź &amp;następny</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="100"/>
        <source>Find &amp;previous</source>
        <translation>Znajdź &amp;poprzedni</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="216"/>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="220"/>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="224"/>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="228"/>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="84"/>
        <source>Uins</source>
        <translation>Numery GG</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="91"/>
        <source>Show status changes</source>
        <translation>Pokaż zmiany statusu</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="231"/>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <location filename="../history.cpp" line="324"/>
        <source>Clear history?</source>
        <translation>Wyczyścić historię?</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <location filename="../history_module.cpp" line="75"/>
        <source>Show history</source>
        <translation>Pokaż historię</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="335"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="336"/>
        <source>Clear history</source>
        <translation>Wyczyść historię</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="140"/>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>dni: %1 godzin: %2</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="354"/>
        <source>The following users were deleted:
%0
Do you want to remove history as well?</source>
        <translation>Następujący użytkownicy zostali usunięci:
%0
Czy chcesz usunąć ich z histori?</translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <location filename="../history_search_dialog.cpp" line="39"/>
        <source>Search history</source>
        <translation>Przeszukaj historię</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="67"/>
        <source>&amp;From:</source>
        <translation>&amp;Od:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="90"/>
        <source>day</source>
        <translation>dzień</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="93"/>
        <source>month</source>
        <translation>miesiąc</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="96"/>
        <source>year</source>
        <translation>rok</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="99"/>
        <source>hour</source>
        <translation>godz.</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="102"/>
        <source>minute</source>
        <translation>min.</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="86"/>
        <source>&amp;To:</source>
        <translation>&amp;Do:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="104"/>
        <source>Find Criteria</source>
        <translation>Kryteria wyszukiwania</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="105"/>
        <source>&amp;Pattern</source>
        <translation>&amp;Wzorzec</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="106"/>
        <source>&amp;Status</source>
        <translation>&amp;Status</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="112"/>
        <source>Pattern</source>
        <translation>Wzorzec</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="114"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="119"/>
        <source>&amp;Reverse find</source>
        <translation>&amp;Szukaj wstecz</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="121"/>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="122"/>
        <source>Reset</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="123"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.2.orig.tar.gz: kadu/modules/history/translations/history_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="53"/>
        <source>Chat</source>
        <translation>Okno rozmowy</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="6"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="9"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="12"/>
        <source>Save history</source>
        <translation>Zapisuj historię</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="14"/>
        <source>Save messages in history</source>
        <translation>Zapisuj wiadomości w historii</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="18"/>
        <source>Status changes</source>
        <translation>Zmiany statusów</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="21"/>
        <source>Don&apos;t show status changes</source>
        <translation>Nie pokazuj zmian statusów</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="23"/>
        <source>Don&apos;t show status changes in history</source>
        <translation>Nie pokazuje zmian statusów w historii</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="26"/>
        <source>Don&apos;t save status changes</source>
        <translation>Nie zapisuj zmian statusów</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="28"/>
        <source>Don&apos;t save status changes in history</source>
        <translation>Nie zapisuje zmian statusów w historii</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="32"/>
        <source>Citation</source>
        <translation>Cytowanie</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="35"/>
        <source>Message citation in chat window</source>
        <translation>Cytowanie historii w oknie rozmowy</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="38"/>
        <source>Don&apos;t cite messages older than</source>
        <translation>Nie cytuj historii starszej niż</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="41"/>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="47"/>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="56"/>
        <source>View history</source>
        <translation>Pokaż historię</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <location filename="../history_dialog.cpp" line="77"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="98"/>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="99"/>
        <source>Find &amp;next</source>
        <translation>Znajdź &amp;następny</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="100"/>
        <source>Find &amp;previous</source>
        <translation>Znajdź &amp;poprzedni</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="216"/>
        <source>Online</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="220"/>
        <source>Busy</source>
        <translation>Zajęty</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="224"/>
        <source>Invisible</source>
        <translation>Ukryty</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="228"/>
        <source>Offline</source>
        <translation>Niedostępny</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="84"/>
        <source>Uins</source>
        <translation>Numery GG</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="91"/>
        <source>Show status changes</source>
        <translation>Pokaż zmiany statusu</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="231"/>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <location filename="../history.cpp" line="324"/>
        <source>Clear history?</source>
        <translation>Wyczyścić historię?</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <location filename="../history_module.cpp" line="75"/>
        <source>Show history</source>
        <translation>Pokaż historię</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="335"/>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="336"/>
        <source>Clear history</source>
        <translation>Wyczyść historię</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="140"/>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>dni: %1 godzin: %2</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="354"/>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation>Następujący użytkownicy zostali usunięci:
%0Czy chcesz usunąć ich z histori?</translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <location filename="../history_search_dialog.cpp" line="39"/>
        <source>Search history</source>
        <translation>Przeszukaj historię</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="67"/>
        <source>&amp;From:</source>
        <translation>&amp;Od:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="90"/>
        <source>day</source>
        <translation>dzień</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="93"/>
        <source>month</source>
        <translation>miesiąc</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="96"/>
        <source>year</source>
        <translation>rok</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="99"/>
        <source>hour</source>
        <translation>godz.</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="102"/>
        <source>minute</source>
        <translation>min.</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="86"/>
        <source>&amp;To:</source>
        <translation>&amp;Do:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="104"/>
        <source>Find Criteria</source>
        <translation>Kryteria wyszukiwania</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="105"/>
        <source>&amp;Pattern</source>
        <translation>&amp;Wzorzec</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="106"/>
        <source>&amp;Status</source>
        <translation>&amp;Status</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="112"/>
        <source>Pattern</source>
        <translation>Wzorzec</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="114"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="119"/>
        <source>&amp;Reverse find</source>
        <translation>&amp;Szukaj wstecz</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="121"/>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="122"/>
        <source>Reset</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="123"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
</TS>
